@@ -7,14 +7,8 @@ use cc;
 use super::Asm;
 
 impl Asm {
-    #[cfg(unix)]
+    #[cfg(not(windows))]
     pub fn generate(&self) {
-        if let Some(ref ret) = self.ret {
-            if ret != "%rax" {
-                panic!("for now, the return argument for an assembly function must be %rax.");
-            }
-        }
-
         let out_dir = env::var("OUT_DIR").unwrap();
         let path = PathBuf::from(out_dir).join(self.name.clone() + ".S");
         let mut output = File::create(&path).unwrap();
@@ -32,14 +26,8 @@ impl Asm {
         cc::Build::new().file(&path).compile(&self.name.clone());
     }
 
-    #[cfg(not(unix))]
+    #[cfg(windows)]
     pub fn generate(&self) {
-        if let Some(ref ret) = self.ret {
-            if ret != "rax" {
-                panic!("for now, the return argument for an assembly function must be %rax.");
-            }
-        }
-
         let out_dir = env::var("OUT_DIR").unwrap();
         let path = PathBuf::from(out_dir).join(self.name.clone() + ".asm");
         let mut output = File::create(&path).unwrap();
